"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var nativescript_lottie_common_1 = require("./nativescript-lottie.common");
var LottieProperty = com.airbnb.lottie.LottieProperty;
var LottieKeyPath = com.airbnb.lottie.model.KeyPath;
var LottieValueCallback = com.airbnb.lottie.value.LottieValueCallback;
var DEFAULT_MAX_PROGRESS = 1;
var DEFAULT_MIN_PROGRESS = 0;
var LottieView = (function (_super) {
    __extends(LottieView, _super);
    function LottieView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(LottieView.prototype, "android", {
        get: function () {
            return this.nativeView;
        },
        enumerable: true,
        configurable: true
    });
    LottieView.prototype.createNativeView = function () {
        return new com.airbnb.lottie.LottieAnimationView(this._context);
    };
    LottieView.prototype.initNativeView = function () {
        var _this = this;
        this.nativeView.addAnimatorListener(new android.animation.Animator.AnimatorListener({
            onAnimationCancel: function (_animator) {
                if (_this.completionBlock) {
                    _this.completionBlock(false);
                }
            },
            onAnimationEnd: function (_animator) {
                if (_this.completionBlock) {
                    _this.completionBlock(true);
                }
            },
            onAnimationRepeat: function (_animator) {
            },
            onAnimationStart: function (_animator) {
            }
        }));
        if (this.src) {
            this.setSrc(this.src);
        }
        if (this.loop) {
            this.nativeView.loop(this.loop);
        }
        if (this.autoPlay) {
            this.playAnimation();
        }
    };
    LottieView.prototype.disposeNativeView = function () {
        this.nativeView.removeAllAnimatorListeners();
        _super.prototype.disposeNativeView.call(this);
    };
    LottieView.prototype[nativescript_lottie_common_1.srcProperty.setNative] = function (src) {
        this.setSrc(src);
    };
    LottieView.prototype.setSrc = function (src) {
        if (this.nativeView) {
            src = /.json$/.test(src) ? src : src + ".json";
            if (this.cacheStrategy) {
                this.nativeView.setAnimation(src, this.cacheStrategy);
            }
            else {
                this.nativeView.setAnimation(src);
            }
            if (this.loop) {
                this.setLoopAnimation(this.loop);
            }
            if (this.autoPlay) {
                this.playAnimation();
            }
        }
    };
    LottieView.prototype[nativescript_lottie_common_1.cacheStrategyProperty.setNative] = function (_cacheStrategy) {
        this.setSrc(this.src);
    };
    LottieView.prototype[nativescript_lottie_common_1.loopProperty.setNative] = function (loop) {
        this.setLoopAnimation(loop);
    };
    LottieView.prototype.setLoopAnimation = function (loop) {
        if (this.nativeView) {
            this.nativeView.loop(loop);
        }
    };
    LottieView.prototype[nativescript_lottie_common_1.autoPlayProperty.setNative] = function (autoPlay) {
        if (autoPlay) {
            if (!this.isAnimating()) {
                this.playAnimation();
            }
        }
        else {
            if (this.isAnimating()) {
                this.cancelAnimation();
            }
        }
    };
    LottieView.prototype.setColorValueDelegateForKeyPath = function (value, keyPath) {
        if (this.nativeView && value && keyPath && keyPath.length) {
            if (keyPath[keyPath.length - 1].toLowerCase() === 'color') {
                keyPath.pop();
                if (keyPath.length === 0) {
                    return;
                }
            }
            var nativeKeyPath_1 = Array.create(java.lang.String, keyPath.length);
            keyPath.forEach(function (key, index) {
                nativeKeyPath_1[index] = new java.lang.String(key);
            });
            this.nativeView.addValueCallback(new LottieKeyPath(nativeKeyPath_1), LottieProperty.COLOR, new LottieValueCallback(new java.lang.Integer(value.android)));
        }
    };
    LottieView.prototype.setOpacityValueDelegateForKeyPath = function (value, keyPath) {
        if (this.nativeView && value && keyPath && keyPath.length) {
            if (keyPath[keyPath.length - 1].toLowerCase() === 'opacity') {
                keyPath.pop();
                if (keyPath.length === 0) {
                    return;
                }
            }
            var nativeKeyPath_2 = Array.create(java.lang.String, keyPath.length);
            keyPath.forEach(function (key, index) {
                nativeKeyPath_2[index] = new java.lang.String(key);
            });
            value = utils_1.clamp(value);
            this.nativeView.addValueCallback(new LottieKeyPath(nativeKeyPath_2), LottieProperty.OPACITY, new LottieValueCallback(new java.lang.Integer(value * 100)));
        }
    };
    LottieView.prototype.playAnimation = function () {
        if (this.nativeView) {
            this.nativeView.setMinAndMaxProgress(DEFAULT_MIN_PROGRESS, DEFAULT_MAX_PROGRESS);
            this.nativeView.playAnimation();
        }
    };
    LottieView.prototype.playAnimationFromProgressToProgress = function (startProgress, endProgress) {
        if (this.nativeView) {
            startProgress = startProgress ? utils_1.clamp(startProgress) : 0;
            endProgress = endProgress ? utils_1.clamp(endProgress) : 1;
            this.nativeView.setMinAndMaxProgress(startProgress, endProgress);
            this.nativeView.playAnimation();
        }
    };
    LottieView.prototype.isAnimating = function () {
        return this.nativeView ? this.nativeView.isAnimating() : false;
    };
    Object.defineProperty(LottieView.prototype, "progress", {
        get: function () {
            return this.nativeView ? this.nativeView.getProgress() : undefined;
        },
        set: function (value) {
            if (this.nativeView && value) {
                this.nativeView.setProgress(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LottieView.prototype, "speed", {
        get: function () {
            return this.nativeView ? this.nativeView.getSpeed() : undefined;
        },
        set: function (value) {
            if (this.nativeView && value) {
                this.nativeView.setSpeed(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LottieView.prototype, "duration", {
        get: function () {
            return this.nativeView ? this.nativeView.getDuration() : undefined;
        },
        enumerable: true,
        configurable: true
    });
    LottieView.prototype.cancelAnimation = function () {
        if (this.nativeView) {
            this.nativeView.cancelAnimation();
        }
    };
    return LottieView;
}(nativescript_lottie_common_1.LottieViewBase));
exports.LottieView = LottieView;
var CacheStrategy;
(function (CacheStrategy) {
    CacheStrategy[CacheStrategy["None"] = com.airbnb.lottie.LottieAnimationView.CacheStrategy.None] = "None";
    CacheStrategy[CacheStrategy["Weak"] = com.airbnb.lottie.LottieAnimationView.CacheStrategy.Weak] = "Weak";
    CacheStrategy[CacheStrategy["Strong"] = com.airbnb.lottie.LottieAnimationView.CacheStrategy.Strong] = "Strong";
})(CacheStrategy = exports.CacheStrategy || (exports.CacheStrategy = {}));
//# sourceMappingURL=nativescript-lottie.android.js.map