"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var nativescript_lottie_common_1 = require("./nativescript-lottie.common");
var LottieView = (function (_super) {
    __extends(LottieView, _super);
    function LottieView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(LottieView.prototype, "ios", {
        get: function () {
            return this.nativeView;
        },
        enumerable: true,
        configurable: true
    });
    LottieView.prototype.createNativeView = function () {
        return LOTAnimationView.alloc().initWithFrame(CGRectMake(0, 0, 0, 0));
    };
    LottieView.prototype.initNativeView = function () {
        this.contentModeDefault();
        if (this.src) {
            this.setSrc(this.src);
        }
        if (this.loop) {
            this.setLoopAnimation(this.loop);
        }
        if (this.autoPlay) {
            this.playAnimation();
        }
    };
    LottieView.prototype[nativescript_lottie_common_1.srcProperty.setNative] = function (src) {
        this.setSrc(src);
    };
    LottieView.prototype.setSrc = function (src) {
        if (this.nativeView) {
            this.nativeView.setAnimationNamed(src);
            if (this.loop) {
                this.setLoopAnimation(this.loop);
            }
            if (this.autoPlay) {
                this.playAnimation();
            }
        }
    };
    LottieView.prototype[nativescript_lottie_common_1.loopProperty.setNative] = function (loop) {
        this.setLoopAnimation(loop);
    };
    LottieView.prototype.setLoopAnimation = function (loop) {
        if (this.nativeView) {
            this.nativeView.loopAnimation = loop;
        }
    };
    LottieView.prototype[nativescript_lottie_common_1.autoPlayProperty.setNative] = function (autoPlay) {
        if (autoPlay) {
            this.setLoopAnimation(this.loop);
            this.contentModeDefault();
            if (!this.isAnimating()) {
                this.playAnimation();
            }
        }
        else {
            if (this.isAnimating()) {
                this.cancelAnimation();
            }
        }
    };
    LottieView.prototype.setColorValueDelegateForKeyPath = function (value, keyPath) {
        if (this.nativeView && value && keyPath && keyPath.length) {
            if (keyPath[keyPath.length - 1].toLowerCase() !== 'color') {
                keyPath.push('Color');
            }
            this.nativeView.setValueDelegateForKeypath(LOTColorValueCallback.withCGColor(value.ios.CGColor), LOTKeypath.keypathWithString(keyPath.join('.')));
        }
    };
    LottieView.prototype.setOpacityValueDelegateForKeyPath = function (value, keyPath) {
        if (this.nativeView && value && keyPath && keyPath.length) {
            if (keyPath[keyPath.length - 1].toLowerCase() !== 'opacity') {
                keyPath.push('Opacity');
            }
            value = utils_1.clamp(value);
            this.nativeView.setValueDelegateForKeypath(LOTNumberValueCallback.withFloatValue(value), LOTKeypath.keypathWithString(keyPath.join('.')));
        }
    };
    LottieView.prototype.playAnimation = function () {
        var _this = this;
        if (this.nativeView) {
            this.nativeView.playWithCompletion(function (animationFinished) {
                if (_this.completionBlock) {
                    _this.completionBlock(animationFinished);
                }
            });
        }
    };
    LottieView.prototype.playAnimationFromProgressToProgress = function (startProgress, endProgress) {
        var _this = this;
        if (this.nativeView) {
            startProgress = startProgress ? utils_1.clamp(startProgress) : 0;
            endProgress = endProgress ? utils_1.clamp(endProgress) : 1;
            this.nativeView.playFromProgressToProgressWithCompletion(startProgress, endProgress, function (animationFinished) {
                if (_this.completionBlock) {
                    _this.completionBlock(animationFinished);
                }
            });
        }
    };
    LottieView.prototype.cancelAnimation = function () {
        if (this.nativeView) {
            this.nativeView.pause();
        }
    };
    LottieView.prototype.isAnimating = function () {
        return this.nativeView ? this.nativeView.isAnimationPlaying : false;
    };
    Object.defineProperty(LottieView.prototype, "progress", {
        get: function () {
            return this.nativeView ? this.nativeView.animationProgress : undefined;
        },
        set: function (value) {
            if (this.nativeView && value) {
                this.nativeView.animationProgress = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LottieView.prototype, "speed", {
        get: function () {
            return this.nativeView ? this.nativeView.animationSpeed : undefined;
        },
        set: function (value) {
            if (this.nativeView && value) {
                this.nativeView.animationSpeed = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LottieView.prototype, "duration", {
        get: function () {
            return this.nativeView ? this.nativeView.animationDuration : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LottieView.prototype, "contentMode", {
        set: function (mode) {
            this._contentMode = mode;
            if (this.nativeView) {
                this.nativeView.contentMode = mode;
            }
        },
        enumerable: true,
        configurable: true
    });
    LottieView.prototype.contentModeDefault = function () {
        if (this.nativeView) {
            if (this._contentMode) {
                this.nativeView.contentMode = this._contentMode;
            }
            else {
                this.nativeView.contentMode = 1;
            }
        }
    };
    return LottieView;
}(nativescript_lottie_common_1.LottieViewBase));
exports.LottieView = LottieView;
//# sourceMappingURL=nativescript-lottie.ios.js.map